// -----------------------------------------------------
// simulate piston in an infinite baffle
// import into Klippel Scanning System 2.0.14
//
// Copyright by Klippel GmbH, Dresden, Germany 2012
// -----------------------------------------------------

// -----------------------------------------------------
// define required import constants
%SCN_FILE_VERSION = 1.1;
%SCN_COORDINATE_SYSTEM = "polar";

// -----------------------------------------------------
// define geometry matrix:
// 	first column  = point number
//	second column = radius in [mm]
//	third column  = angle in [rad]
//	fourth column = height in [mm]
//
// outer radius = 100mm
// inner radius = 00mm
// resolution = 40 radial steps
// resolution = 1 angular steps
r_max = 100;
r_min = 0;
rcount = 40;
phicount = 1;
rand("seed",0);

r = ones(phicount,1)*(r_min:(r_max-r_min)/(rcount-1):r_max);
phi = zeros(1,rcount);
n= rcount*phicount;

// define profile line with given resolution
geometry = [(1:n)' , r(:), phi(:), zeros(n,1)];

// -----------------------------------------------------
// define frequency vector
frequency = [100,1000,10000];

// -----------------------------------------------------
// define displacement amplitude:
// for each point specified in geometry array
// for each frequency 
// amplitude given in dB [mm / V]

// displacement = 1mm from 100Hz to 1kHz, drops down to 1um for 10kHz
amplitude = 20*log10(matrix(ones(phicount,1)*ones(1,rcount), n, 1)*[1e-3,1e-3,1e-6]);

// -----------------------------------------------------
// define displacement phase:
// for each point specified in geometry array
// for each frequency
// phase given in [rad]

// phase is random
phase = 2*%pi*matrix( ones(phicount,1)*rand(1,rcount), n, 1)*[1,1,1];

